[![Build Status](https://travis-ci.org/AWehrhahn/PyReduce.svg?branch=master)](https://travis-ci.org/AWehrhahn/PyReduce)
[![Documentation Status](https://readthedocs.org/projects/pyreduce-astro/badge/?version=latest)](https://pyreduce-astro.readthedocs.io/en/latest/?badge=latest)
[![Updates](https://pyup.io/repos/github/AWehrhahn/PyReduce/shield.svg)](https://pyup.io/repos/github/AWehrhahn/PyReduce/)

# PyREDUCE

A port of [REDUCE](http://www.astro.uu.se/~piskunov/RESEARCH/REDUCE/) to Python3.

Documentation is available at [ReadTheDocs](https://pyreduce-astro.readthedocs.io/en/latest/index.html).
